# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *
from xml.etree.ElementTree import parse


def install():
    bin_name = glob.glob("TreeSizeFreeSetup*.exe")[0]
    app_uninstallkey = "TreeSize Free_is1"

    install_exe_if_needed(
        bin_name,
        silentflags="/VERYSILENT /SUPPRESSMSGBOXES /NORESTART /SP-",
        key=app_uninstallkey,
        min_version=control.get_software_version(),
    )

    # Adding QuietUninstallString
    quiet_uninstall_string = installed_softwares(uninstallkey=app_uninstallkey)[0]["uninstall_string"] + " /VERYSILENT /SUPPRESSMSGBOXES /NORESTART"
    register_uninstall(app_uninstallkey, quiet_uninstall_string=quiet_uninstall_string)


def session_cleanup():
    print("Removing the TreeSize shortcut on user appdata")
    remove_user_programs_menu_shortcut('TreeSizeFree.exe')


def session_setup():
    print("Disabling: update check, pop-ups and context menu once")
    user_conf_dir = makepath(application_data, "JAM Software", "TreeSize Free")
    user_conf_file = makepath(user_conf_dir, "GlobalOptions.xml")

    user_conf_content = """<?xml version="1.0" encoding="UTF-8"?>
<GlobalOptions Version="3" AppVersion="0" Type="TGlobalOptions">
	<ContextMenuEntries>4</ContextMenuEntries>
	<AskForRestartAsAdministrator>False</AskForRestartAsAdministrator>
	<DoNotAskAgainList Type="TSerializableStringIntDictionary"></DoNotAskAgainList>
	<CheckForUpdateOptions Type="TCheckForUpdateOptions">
		<LatestOnlineVersion>0</LatestOnlineVersion>
		<LastAutomaticCheckForUpdate>0</LastAutomaticCheckForUpdate>
		<CheckForUpdatesAutomatically>False</CheckForUpdatesAutomatically>
	</CheckForUpdateOptions>
</GlobalOptions>
"""
    if not isdir(user_conf_dir):
        mkdirs(user_conf_dir)

    if isfile(user_conf_file) and os.path.getsize(user_conf_file) != 0:
        tree = parse(user_conf_file)
        root = tree.getroot()

        # Modify ContextMenuEntries
        context_menu_entries = root.find('ContextMenuEntries')
        if context_menu_entries is not None:
            context_menu_entries.text = '4'

        # Modify AskForRestartAsAdministrator
        ask_restart = root.find('AskForRestartAsAdministrator')
        if ask_restart is not None:
            ask_restart.text = 'False'

        # Modify CheckForUpdateOptions
        update_options = root.find('CheckForUpdateOptions')
        if update_options is not None:
            latest_version = update_options.find('LatestOnlineVersion')
            latest_version.text = '0'

            last_check = update_options.find('LastAutomaticCheckForUpdate')
            last_check.text = '0'

            auto_check = update_options.find('CheckForUpdatesAutomatically')
            auto_check.text = 'False'

        tree.write(user_conf_file, encoding='utf-8', xml_declaration=True)
    else:
        with open(user_conf_file, 'w') as xml_file:
            xml_file.write(user_conf_content)